@@ -8,7 +8,7 @@ for V in cp36-cp36m cp35-cp35m cp27-cp27m cp27-cp27mu; do
     $PYBIN/pip install pytest
     pushd test          # prevent importing msgpack package in current directory.
     $PYBIN/python -c 'import sys; print(hex(sys.maxsize))'
-    $PYBIN/python -c 'from msgpack import _packer, _unpacker'
+    $PYBIN/python -c 'from msgpack import _cmsgpack'  # Ensure extension is available
     $PYBIN/pytest -v .
     popd
 done
