@@ -7,7 +7,10 @@ from msgpack import packb, unpackb
 def test_unpack_buffer():
     from array import array
     buf = array('b')
-    buf.fromstring(packb((b'foo', b'bar')))
+    try:
+        buf.frombytes(packb((b'foo', b'bar')))
+    except AttributeError:  # PY2
+        buf.fromstring(packb((b'foo', b'bar')))
     obj = unpackb(buf, use_list=1)
     assert [b'foo', b'bar'] == obj
 
